@@ -8,7 +8,11 @@ from borgmatic.hooks import healthchecks as module
 def test_destroy_monitor_removes_healthchecks_handler():
     logger = logging.getLogger()
     original_handlers = list(logger.handlers)
-    logger.addHandler(module.Forgetful_buffering_handler(byte_capacity=100, log_level=1))
+    module.borgmatic.hooks.logs.add_handler(
+        module.borgmatic.hooks.logs.Forgetful_buffering_handler(
+            identifier=module.HANDLER_IDENTIFIER, byte_capacity=100, log_level=1
+        )
+    )
 
     module.destroy_monitor(flexmock(), flexmock(), flexmock(), flexmock(), flexmock())
 
