@@ -10,18 +10,23 @@ from ..test_verbosity import insert_logging_mock
 def insert_execute_command_mock(
     command,
     output_log_level=logging.INFO,
+    working_directory=None,
     borg_local_path='borg',
     borg_exit_codes=None,
     capture=True,
 ):
     flexmock(module.environment).should_receive('make_environment')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
+        working_directory,
+    )
     flexmock(module).should_receive('execute_command').with_args(
         command,
         output_file=None if capture else module.DO_NOT_CAPTURE,
         output_log_level=output_log_level,
+        extra_environment=None,
+        working_directory=working_directory,
         borg_local_path=borg_local_path,
         borg_exit_codes=borg_exit_codes,
-        extra_environment=None,
     ).once()
 
 
@@ -353,3 +358,26 @@ def test_export_tar_archive_calls_borg_with_stdout_destination_path():
         local_borg_version='1.2.3',
         global_arguments=flexmock(log_json=False),
     )
+
+
+def test_export_tar_archive_calls_borg_with_working_directory():
+    flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        ('repo::archive',)
+    )
+    insert_execute_command_mock(
+        ('borg', 'export-tar', 'repo::archive', 'test.tar'),
+        working_directory='/working/dir',
+    )
+
+    module.export_tar_archive(
+        dry_run=False,
+        repository_path='repo',
+        archive='archive',
+        paths=[],
+        destination_path='test.tar',
+        config={'working_directory': '/working/dir'},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+    )
