@@ -11,12 +11,20 @@ VERSION = '1.2.3'
 
 
 def insert_execute_command_and_capture_output_mock(
-    command, borg_local_path='borg', borg_exit_codes=None, version_output=f'borg {VERSION}'
+    command,
+    working_directory=None,
+    borg_local_path='borg',
+    borg_exit_codes=None,
+    version_output=f'borg {VERSION}',
 ):
     flexmock(module.environment).should_receive('make_environment')
+    flexmock(module.borgmatic.config.paths).should_receive('get_working_directory').and_return(
+        working_directory,
+    )
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         command,
         extra_environment=None,
+        working_directory=working_directory,
         borg_local_path=borg_local_path,
         borg_exit_codes=borg_exit_codes,
     ).once().and_return(version_output)
@@ -68,3 +76,12 @@ def test_local_borg_version_with_invalid_version_raises():
 
     with pytest.raises(ValueError):
         module.local_borg_version({})
+
+
+def test_local_borg_version_calls_borg_with_working_directory():
+    insert_execute_command_and_capture_output_mock(
+        ('borg', '--version'), working_directory='/working/dir'
+    )
+    flexmock(module.environment).should_receive('make_environment')
+
+    assert module.local_borg_version({'working_directory': '/working/dir'}) == VERSION
