@@ -73,7 +73,18 @@ def test_dump_data_sources_dumps_each_database():
             dry_run_label=object,
         ).and_return(process).once()
 
-    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == processes
+    assert (
+        module.dump_data_sources(
+            databases,
+            {},
+            'test.yaml',
+            config_paths=('test.yaml',),
+            borgmatic_runtime_directory='/run/borgmatic',
+            source_directories=[],
+            dry_run=False,
+        )
+        == processes
+    )
 
 
 def test_dump_data_sources_dumps_with_password():
@@ -94,7 +105,15 @@ def test_dump_data_sources_dumps_with_password():
         dry_run_label=object,
     ).and_return(process).once()
 
-    assert module.dump_data_sources([database], {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources(
+        [database],
+        {},
+        'test.yaml',
+        config_paths=('test.yaml',),
+        borgmatic_runtime_directory='/run/borgmatic',
+        source_directories=[],
+        dry_run=False,
+    ) == [process]
 
 
 def test_dump_data_sources_dumps_all_databases_at_once():
@@ -112,7 +131,15 @@ def test_dump_data_sources_dumps_all_databases_at_once():
         dry_run_label=object,
     ).and_return(process).once()
 
-    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources(
+        databases,
+        {},
+        'test.yaml',
+        config_paths=('test.yaml',),
+        borgmatic_runtime_directory='/run/borgmatic',
+        source_directories=[],
+        dry_run=False,
+    ) == [process]
 
 
 def test_dump_data_sources_dumps_all_databases_separately_when_format_configured():
@@ -132,7 +159,18 @@ def test_dump_data_sources_dumps_all_databases_separately_when_format_configured
             dry_run_label=object,
         ).and_return(process).once()
 
-    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == processes
+    assert (
+        module.dump_data_sources(
+            databases,
+            {},
+            'test.yaml',
+            config_paths=('test.yaml',),
+            borgmatic_runtime_directory='/run/borgmatic',
+            source_directories=[],
+            dry_run=False,
+        )
+        == processes
+    )
 
 
 def test_database_names_to_dump_runs_mariadb_with_list_options():
@@ -434,7 +472,15 @@ def test_dump_data_sources_errors_for_missing_all_databases():
     flexmock(module).should_receive('database_names_to_dump').and_return(())
 
     with pytest.raises(ValueError):
-        assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False)
+        assert module.dump_data_sources(
+            databases,
+            {},
+            'test.yaml',
+            config_paths=('test.yaml',),
+            borgmatic_runtime_directory='/run/borgmatic',
+            source_directories=[],
+            dry_run=False,
+        )
 
 
 def test_dump_data_sources_does_not_error_for_missing_all_databases_with_dry_run():
@@ -445,7 +491,18 @@ def test_dump_data_sources_does_not_error_for_missing_all_databases_with_dry_run
     )
     flexmock(module).should_receive('database_names_to_dump').and_return(())
 
-    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=True) == []
+    assert (
+        module.dump_data_sources(
+            databases,
+            {},
+            'test.yaml',
+            config_paths=('test.yaml',),
+            borgmatic_runtime_directory='/run/borgmatic',
+            source_directories=[],
+            dry_run=True,
+        )
+        == []
+    )
 
 
 def test_restore_data_source_dump_runs_mariadb_to_restore():
@@ -473,6 +530,7 @@ def test_restore_data_source_dump_runs_mariadb_to_restore():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -501,6 +559,7 @@ def test_restore_data_source_dump_runs_mariadb_with_options():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -531,6 +590,7 @@ def test_restore_data_source_dump_runs_non_default_mariadb_with_options():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -568,6 +628,7 @@ def test_restore_data_source_dump_runs_mariadb_with_hostname_and_port():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -596,6 +657,7 @@ def test_restore_data_source_dump_runs_mariadb_with_username_and_password():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -645,6 +707,7 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
             'username': 'cliusername',
             'password': 'clipassword',
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -696,6 +759,7 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -717,4 +781,5 @@ def test_restore_data_source_dump_with_dry_run_skips_restore():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
