@@ -41,7 +41,18 @@ def test_dump_data_sources_runs_mongodump_for_each_database():
             run_to_completion=False,
         ).and_return(process).once()
 
-    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == processes
+    assert (
+        module.dump_data_sources(
+            databases,
+            {},
+            'test.yaml',
+            config_paths=('test.yaml',),
+            borgmatic_runtime_directory='/run/borgmatic',
+            source_directories=[],
+            dry_run=False,
+        )
+        == processes
+    )
 
 
 def test_dump_data_sources_with_dry_run_skips_mongodump():
@@ -53,7 +64,18 @@ def test_dump_data_sources_with_dry_run_skips_mongodump():
     flexmock(module.dump).should_receive('create_named_pipe_for_dump').never()
     flexmock(module).should_receive('execute_command').never()
 
-    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=True) == []
+    assert (
+        module.dump_data_sources(
+            databases,
+            {},
+            'test.yaml',
+            config_paths=('test.yaml',),
+            borgmatic_runtime_directory='/run/borgmatic',
+            source_directories=[],
+            dry_run=True,
+        )
+        == []
+    )
 
 
 def test_dump_data_sources_runs_mongodump_with_hostname_and_port():
@@ -82,7 +104,15 @@ def test_dump_data_sources_runs_mongodump_with_hostname_and_port():
         run_to_completion=False,
     ).and_return(process).once()
 
-    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources(
+        databases,
+        {},
+        'test.yaml',
+        config_paths=('test.yaml',),
+        borgmatic_runtime_directory='/run/borgmatic',
+        source_directories=[],
+        dry_run=False,
+    ) == [process]
 
 
 def test_dump_data_sources_runs_mongodump_with_username_and_password():
@@ -120,7 +150,15 @@ def test_dump_data_sources_runs_mongodump_with_username_and_password():
         run_to_completion=False,
     ).and_return(process).once()
 
-    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources(
+        databases,
+        {},
+        'test.yaml',
+        config_paths=('test.yaml',),
+        borgmatic_runtime_directory='/run/borgmatic',
+        source_directories=[],
+        dry_run=False,
+    ) == [process]
 
 
 def test_dump_data_sources_runs_mongodump_with_directory_format():
@@ -137,7 +175,18 @@ def test_dump_data_sources_runs_mongodump_with_directory_format():
         shell=True,
     ).and_return(flexmock()).once()
 
-    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == []
+    assert (
+        module.dump_data_sources(
+            databases,
+            {},
+            'test.yaml',
+            config_paths=('test.yaml',),
+            borgmatic_runtime_directory='/run/borgmatic',
+            source_directories=[],
+            dry_run=False,
+        )
+        == []
+    )
 
 
 def test_dump_data_sources_runs_mongodump_with_options():
@@ -163,7 +212,15 @@ def test_dump_data_sources_runs_mongodump_with_options():
         run_to_completion=False,
     ).and_return(process).once()
 
-    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources(
+        databases,
+        {},
+        'test.yaml',
+        config_paths=('test.yaml',),
+        borgmatic_runtime_directory='/run/borgmatic',
+        source_directories=[],
+        dry_run=False,
+    ) == [process]
 
 
 def test_dump_data_sources_runs_mongodumpall_for_all_databases():
@@ -181,7 +238,15 @@ def test_dump_data_sources_runs_mongodumpall_for_all_databases():
         run_to_completion=False,
     ).and_return(process).once()
 
-    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources(
+        databases,
+        {},
+        'test.yaml',
+        config_paths=('test.yaml',),
+        borgmatic_runtime_directory='/run/borgmatic',
+        source_directories=[],
+        dry_run=False,
+    ) == [process]
 
 
 def test_build_dump_command_with_username_injection_attack_gets_escaped():
@@ -218,6 +283,7 @@ def test_restore_data_source_dump_runs_mongorestore():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -257,6 +323,7 @@ def test_restore_data_source_dump_runs_mongorestore_with_hostname_and_port():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -304,6 +371,7 @@ def test_restore_data_source_dump_runs_mongorestore_with_username_and_password()
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -359,6 +427,7 @@ def test_restore_data_source_dump_with_connection_params_uses_connection_params_
             'username': 'cliusername',
             'password': 'clipassword',
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -414,6 +483,7 @@ def test_restore_data_source_dump_without_connection_params_uses_restore_params_
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -443,6 +513,7 @@ def test_restore_data_source_dump_runs_mongorestore_with_options():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -480,6 +551,7 @@ def test_restore_databases_dump_runs_mongorestore_with_schemas():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -509,6 +581,7 @@ def test_restore_data_source_dump_runs_psql_for_all_database_dump():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -532,6 +605,7 @@ def test_restore_data_source_dump_with_dry_run_skips_restore():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
 
 
@@ -560,4 +634,5 @@ def test_restore_data_source_dump_without_extract_process_restores_from_disk():
             'username': None,
             'password': None,
         },
+        borgmatic_runtime_directory='/run/borgmatic',
     )
